capture log close
clear
clear mata
clear matrix
set mem 500m
set more off
graph drop _all


#delimit ;

*	************************************************************************ *;
* 	File-Name: CoupModels1.do												 *;
*	Date:  07/10/2018														 *;
*	Purpose:   Replication files used to generate Tables 1 and 2 and Figure  *;
*	2 in Hollyer, Rosendorff & Vreeland, JCR, 2018.							 *;
*	************************************************************************ *;

*Set working directory to replication folder.;

cd "c:\users\james\desktop\dropbox\transparency_and_democracy\whyautocratictransparency\jcrmaterials\replicationfiles\";

use "CoupLeaderRemoval.dta";

*Need to generate a year counter for years in which leaders are not removed;
*to generate a time variable.;

gen yearMDY="";

sum year;
local num=r(N);

forvalues i=1(1)`num'{;
	local yr=year[`i'];
	replace yearMDY="12/31/`yr'" if _n==`i';
	};

gen eyear=date(yearMDY, "MDY");
format eyear %d;

replace eyear = eenddate if failyear==1;

*Also need to generate an "exit by other means" variable.;
gen failnotcoup=1 if failyear==1 & failcoup==0;

rename ccode cowcode;

merge m:1 cowcode year using "c:\users\james\desktop\dropbox\transparency_and_democracy\whyautocratictransparency\dataanalysis\gwf autocratic regimes\gwftscs.dta";

*there are some observations which are in Svolik but not in GWF -- likely due to discrepancies over the definition of democracy.;

drop if _merge==2;
drop _merge;
sort wdicode year;

gen lag_gwf_party=gwf_party[_n-1] if wdicode==wdicode[_n-1];
gen lag_gwf_personal=gwf_personal[_n-1] if wdicode==wdicode[_n-1];

stset eyear, id(leadid) origin(estartdate) failure(failcoup) 
exit(failnotcoup==1) scale(365.25);

stcox lag_transparency lag_growth lag_GDP lag_monmil, 
nohr strata(ever_past_coup) cluster(wdicode);

estimates store coupfrequency1;

estat phtest, rank detail;

stcox lag_transparency lag_growth lag_GDP lag_monmil, 
nohr strata(hist_past_coups) cluster(wdicode);

estimates store coupfrequency3;

estat phtest, rank detail;

stcox lag_transparency lag_growth lag_GDP lag_monmil ever_past_coup, 
nohr cluster(wdicode);

estimates store coupfrequency5;

estat phtest, rank detail;

preserve;

*We ecounter a violation of the proportional hazards assumption with the gwf_party variable.;
*Moreover, it seems that this specification does not call for the quadratic of GDP per capita.;
*We drop the quadratic and add an interaction of the lag_gwf_party variable with time.;

stsplit, at(failures);

gen lag_party_t=lag_gwf_party*_t;

stcox lag_transparency lag_growth lag_GDP lag_gwf_party lag_party_t lag_gwf_personal, 
nohr strata(ever_past_coup) cluster(wdicode);

estimates store coupfrequency2;

estat phtest, rank detail;

stcox lag_transparency lag_growth lag_GDP lag_gwf_party lag_party_t lag_gwf_personal, 
nohr strata(hist_past_coups) cluster(wdicode);

estimates store coupfrequency4;

estat phtest, rank detail;

stcox lag_transparency lag_growth lag_GDP lag_gwf_party lag_party_t lag_gwf_personal ever_past_coup, 
nohr cluster(wdicode);

estimates store coupfrequency6;

estat phtest, rank detail;

**The following exports Table 2 in the paper.

*estout coupfrequency1  coupfrequency3  coupfrequency5 
using "c:\users\james\desktop\dropbox\transparency_and_democracy\whyautocratictransparency\dataanalysis\coupfrequencyDD.tex",
cells(b(star fmt(3)) ci(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) 
stats(N_clust N_fail, labels("\# of Subjects" "\# of Failures")) style(tex) replace;


**The following exports Table 1 in the paper.

*estout coupfrequency2  coupfrequency4  coupfrequency6 
using "c:\users\james\desktop\dropbox\transparency_and_democracy\whyautocratictransparency\dataanalysis\coupfrequencyGWF.tex",
cells(b(star fmt(3)) ci(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) 
stats(N_clust N_fail, labels("\# of Subjects" "\# of Failures")) style(tex) replace;

**The following generates Figure 2 in the paper.

stcox lag_transparency lag_growth lag_GDP lag_gwf_party lag_party_t lag_gwf_personal ever_past_coup, 
nohr cluster(wdicode);

sum lag_transparency, detail;

local lowtrans=r(p10);
local hightrans=r(p90);

stcurve, hazard at1(lag_transparency=`lowtrans' lag_gwf_party=0 lag_party_t=0 lag_gwf_personal=0 
ever_past_coup=0)
at2(lag_transparency=`hightrans' lag_gwf_party=0 lag_party_t=0 lag_gwf_personal=0
ever_past_coup=0)
graphregion(fcolor(white)) ytitle(Hazard Rate) xtitle(Spell Length - Years)
scheme(s2mono) legend(label(1 Low Transparency) label(2 High Transparency)) title(Hazard of Leader Removal via Coup)
nob;

**graph export "c:\users\james\desktop\dropbox\transparency_and_democracy\whyautocratictransparency\CoupHazard.png",
width(1000) replace;


