#File Name: WhyTransDDTable.R
#Author: James Hollyer
#Date: 7/10/2018

library(arm)
library(foreign)
library(rjags)
library(R2jags)
library(data.table)
#install.packages("xtable", dep=TRUE)
library(xtable)
library(gdata)


setwd("c:/users/james/desktop/dropbox/transparency_and_democracy/whyautocratictransparency/jcrmaterials/replicationfiles/")

load("WhyTransMultilevelDD.RData")

ResultsTable<-matrix(,nrow=32, ncol=5)
CredIntervals<-matrix(,nrow=1, ncol=2)

VariableNames <- c(" ", " ", "Single Party", "Multi-Party", "Legislature", "Hierarchical", "Communist", "Fuel Exporter", "Lag Transparency", "GDP per capita",
"GDP", "Ec. Openness", "Growth", "Gov't Consumption", "New Leader")

ResultsTable[1:2,2] <- VariableNames[1:2]
for(i in 3:28){
  j <- i%%2==0
  if(j==FALSE){
    k <- (i+1)/2+1
    ResultsTable[i,2] <- VariableNames[k]
  }
}

ResultsTable[29,2] <- "Cubic Time"
ResultsTable[30,2] <- "Polynomial"
ResultsTable[31,2] <- "# Obs"
ResultsTable[32,2] <- "# Regimes"

for(i in 3:5){
    ResultsTable[30,i] <- "checkmark"
    ResultsTable[31,i] <- NROW(RegimeYearData)
    ResultsTable[32,i] <- NROW(RegimeData)
  }

attach.jags(results.full)

for(i in 3:14){
  j <- i%%2==0
  if (j==FALSE){
    k<-(i-1)/2 +1
    ResultsTable[i,3]<- round(mean(gamma[,k]),3)
    }
  if (j==TRUE){
    k<-i/2 
    CredIntervals <-HPDinterval(as.mcmc(as.matrix(gamma[,k])),prob=0.95)
    ResultsTable[i,3] <- paste("[",round(CredIntervals[,1],3),", ",round(CredIntervals[,2],3),"]",sep="")
  }
}

ResultsTable[15,3] <- round(mean(rho),3)
CredIntervals <-HPDinterval(as.mcmc(as.matrix(rho)),prob=0.95)
ResultsTable[16,3] <- paste("[",round(CredIntervals[,1],3),", ",round(CredIntervals[,2],3),"]",sep="")

for(i in 17:28){
  j <- i%%2==0
  if (j==FALSE){
    k<-(i-1)/2 -7
    ResultsTable[i,3] <- round(mean(beta[,k]),3)
    }
  if(j==TRUE){
    k<-i/2 - 8
    CredIntervals <-HPDinterval(as.mcmc(as.matrix(beta[,k])),prob=0.95)
    ResultsTable[i,3] <- paste("[",round(CredIntervals[,1],3),", ",round(CredIntervals[,2],3),"]",sep="")
  }
}

attach.jags(results.pars)

ResultsTable[13,4]<-round(mean(gamma[,3]),3)
CredIntervals <-HPDinterval(as.mcmc(as.matrix(gamma[,3])),prob=0.95)
ResultsTable[14,4] <- paste("[",round(CredIntervals[,1],3),", ",round(CredIntervals[,2],3),"]",sep="")
ResultsTable[9,4]<-round(mean(gamma[,2]),3)
CredIntervals <-HPDinterval(as.mcmc(as.matrix(gamma[,2])),prob=0.95)
ResultsTable[10,4] <- paste("[",round(CredIntervals[,1],3),", ",round(CredIntervals[,2],3),"]",sep="")
ResultsTable[15,4] <- round(mean(rho),3)
CredIntervals <-HPDinterval(as.mcmc(as.matrix(rho)),prob=0.95)
ResultsTable[16,4] <- paste("[",round(CredIntervals[,1],3),", ",round(CredIntervals[,2],3),"]",sep="")

for(i in 17:20){
  j <- i%%2==0
  if(j==FALSE){
    k<-(i-1)/2 - 7
    ResultsTable[i,4] <- round(mean(beta[,k]),3)
    }
  if(j==TRUE){
    k<-i/2 - 8
    CredIntervals <-HPDinterval(as.mcmc(as.matrix(beta[,k])),prob=0.95)
    ResultsTable[i,4] <- paste("[",round(CredIntervals[,1],3),", ",round(CredIntervals[,2],3),"]",sep="")
  }
}

for(i in 25:28){
  j <- i%%2==0
  if(j==FALSE){
    k<-(i-1)/2 - 9
    ResultsTable[i,4] <- round(mean(beta[,k]),3)
    }
  if(j==TRUE){
    k<-i/2 - 10
     CredIntervals <-HPDinterval(as.mcmc(as.matrix(beta[,k])),prob=0.95)
    ResultsTable[i,4] <- paste("[",round(CredIntervals[,1],3),", ",round(CredIntervals[,2],3),"]",sep="")
  }
}

attach.jags(results.verypars)

ResultsTable[13,5]<-round(mean(gamma[,3]),3)
CredIntervals <-HPDinterval(as.mcmc(as.matrix(gamma[,3])),prob=0.95)
ResultsTable[14,5] <- paste("[",round(CredIntervals[,1],3),", ",round(CredIntervals[,2],3),"]",sep="")
ResultsTable[9,5]<-round(mean(gamma[,2]),3)
CredIntervals <-HPDinterval(as.mcmc(as.matrix(gamma[,2])),prob=0.95)
ResultsTable[10,5] <- paste("[",round(CredIntervals[,1],3),", ",round(CredIntervals[,2],3),"]",sep="")
ResultsTable[15,5] <- round(mean(rho),3)
CredIntervals <-HPDinterval(as.mcmc(as.matrix(rho)),prob=0.95)
ResultsTable[16,5] <- paste("[",round(CredIntervals[,1],3),", ",round(CredIntervals[,2],3),"]",sep="")
ResultsTable[27,5] <- round(mean(beta[,1]),3)
CredIntervals <-HPDinterval(as.mcmc(as.matrix(beta[,1])),prob=0.95)
ResultsTable[28,5] <- paste("[",round(CredIntervals[,1],3),", ",round(CredIntervals[,2],3),"]",sep="")



DDTable<-xtable(ResultsTable, caption="Models of Disclosure: DD Data")

sink("DisclosureDDTable.tex")
print(DDTable, include.rownames=FALSE)
sink()
